#This R script is used in the Example 2. the Post-analysis of ROH Using Horse Genotype Samples in HandyCNV Paper.
#
# Citation: Zhou J, Liu L, Lopdell TJ, Garrick DJ and Shi Y (2021). 
#           HandyCNV: Standardized Summary, Annotation, Comparison and Visualization of CNV, CNVR, and ROH. 
#           Front. Genet. 12:731355. doi: 10.3389/fgene.2021.731355

#The genotype data used in Example 2 can be found in Brandon D. Velie’s study, which was public available via Figshare (DOI: 10.6084/m9.figshare.3145759).

#To run through this example,require to download the genotype data and install following packages 
install.packages("remotes") #Skip this step if you had install this package before
remotes::install_github(repo = "JH-Zhou/HandyCNV@v1.1.4")
library(HandyCNV)
library(data.table)
library(dplyr)

#Step 1. Setup the working directory in your computer and prepare genotype data by following code
setwd("c:/localpath")
map <- fread("Exmoor_PLINK_g.map")
ped <- fread("Exmoor_PLINK_g.ped", skip = 1, header = F)
five_cloumn <- data.frame(A_1 = seq(1, 285, by =1),
                          A_2 = c(rep(0, 285)),
                          A_3 = c(rep(0, 285)),
                          A_4 = c(rep(0, 285)),
                          A_5 = c(rep(0, 285)))

new_ped <- cbind(five_cloumn[, 1], ped[,1], five_cloumn[, 2:5], ped[,2:670797])
fwrite(new_ped, file = "Exmoor_PLINK_g_n.ped", quote = F, col.names = F, sep = "\t")
fwrite(map, file = "Exmoor_PLINK_g_n.map", quote = F, col.names = F, sep = "\t")

#Step 2. check SNP density from Map file
jpeg(filename = 'SNP_Density.jpeg', width = 25, height = 20, res = 350, units = "cm")
plot_snp_density(map = map, max_chr = 36, top_density = 418, low_density = 125, ncol_1 = 6, legend_position = c(0.94, 0.06))
dev.off()

#Step 3. calling ROH by plink 1.9
shell("plink --file Exmoor_PLINK_g_n --chr-set 36 --make-bed --out horse")
shell("plink --bfile horse --chr-set 36 --homozyg-kb 1 --homozyg-snp 200 --homozyg-window-het 1 --homozyg-window-missing 1")

#Step 4. Summary of ROH, plot distribution of ROH frequency, and calculate inbreeding coefficient
roh_window(roh = "plink.hom",length_autosomal = 2474.912402, max_chr = 36, window_size = 0.01, length_group = c(1.25, 5.00))

#Step 5. Visualize ROH by chromosome
#read ROH results
clean_roh <- fread("plink.hom")
#Visualize ROH on Chromosome 22
roh_visual(clean_roh = clean_roh, chr_id = 22)
#Zoom into 22.81-23.22Mb on Chr 22
roh_visual(clean_roh = clean_roh, target_region = c(22,22.81,23.22))

#Step 6. Download reference genome
get_refgene() # check the name of reference gene list 
equCab2 <- get_refgene("Horse_equCab2.0_UCSC")

#Step 7. Annotate gene for ROH
high_freq_roh <- fread("roh_window/high_freq_roh.txt") #read high frequent ROH regions
call_gene(refgene = equCab2, interval = high_freq_roh)

#Step 8. Visualize ROH that contains genes
roh_visual(clean_roh = clean_roh, target_region = c(22,43.4,47), refgene = equCab2)
equCab2 %>% filter(name2 =="GABPB1") %>% select(Chr, Start, End)
roh_visual(clean_roh = clean_roh, target_region = c(1,139.870285, 139.898179))

high_freq_roh_gene <- fread("call_gene/interval_gene_summarise_table.txt") %>% filter(n_gene >= 1)
for (i in 1:nrow(high_freq_roh_gene)) {
  roh_visual(clean_roh = clean_roh, target_region = c(high_freq_roh_gene$Chr[i],high_freq_roh_gene$Start[i]/1000000,high_freq_roh_gene$End[i]/1000000), refgene = equCab2, folder = "ROH_GENE")
}


#Step 9. Phasing genotype on chromosome 22 by Beagle 5.1
shell("plink --chr 1 --chr-set 36 --bfile horse --out horse_chr1 --recode vcf")
shell("java -Xmx966m -jar beagle.18May20.d20.jar window=100 ne=285 gt=horse_chr1.vcf gp=true out=orse_chr1_phased")

#Step 10. Get the haplotype for GABPB1  gene
geno_chr1 <- prep_phased(phased_geno = "orse_chr1_phased.vcf.gz", convert_letter = T)
GABPB1_pos <- closer_snp(phased_input = geno_chr1$map, chr = 1, start = 139.870285, end = 139.898179)
GABPB1_haplotype <- get_haplotype(geno = geno_chr1, pos = GABPB1_pos)
data.frame(table(GABPB1_haplotype$hap_type$Recode_Type))
GABPB1_haplotype$hap_index

